@@ -1,22 +1,23 @@
 #
 # BZ::Client::XMLRPC::Array - Event handler for parsing a single XML-RPC array.
 #
+package BZ::Client::XMLRPC::Array;
+
 use strict;
 use warnings "all";
 
-package BZ::Client::XMLRPC::Array;
-$BZ::Client::XMLRPC::Array::VERSION = '1.062_2';
 use BZ::Client::XMLRPC::Handler();
 
+our $VERSION = 1.0;
 our @ISA = qw(BZ::Client::XMLRPC::Handler);
 
-sub init {
+sub init($$) {
     my($self,$parser) = @_;
     $self->SUPER::init($parser);
     $self->{'result'} = [];
 }
 
-sub start {
+sub start($$) {
     my($self,$name) = @_;
     my $l = $self->inc_level();
     if ($l == 0) {
@@ -45,46 +46,9 @@ sub start {
     return $l;
 }
 
-sub result {
-    my $self = shift;
+sub result($) {
+    my($self) = shift;
     return $self->{'result'};
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-BZ::Client::XMLRPC::Array
-
-=head1 VERSION
-
-version 1.062_2
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Dean Hamstead <dean@bytefoundry.com.au>
-
-=item *
-
-Jochen Wiedmann <jochen.wiedmann@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Dean Hamstad.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
