@@ -1,17 +1,18 @@
 #
 # BZ::Client::XMLRPC::Response - Event handler for parsing an XML-RPC response.
 #
+package BZ::Client::XMLRPC::Response;
+
 use strict;
 use warnings "all";
 
-package BZ::Client::XMLRPC::Response;
-$BZ::Client::XMLRPC::Response::VERSION = '1.062_2';
 use BZ::Client::XMLRPC::Handler();
 use BZ::Client::XMLRPC::Value();
 
+our $VERSION = 1.0;
 our @ISA = qw(BZ::Client::XMLRPC::Handler);
 
-sub start {
+sub start($$) {
     my($self,$name) = @_;
     my $l = $self->inc_level();
     if ($l == 0) {
@@ -74,58 +75,21 @@ sub start {
     }
 }
 
-sub end {
+sub end($$) {
     my($self, $name) = @_;
     my $l = $self->SUPER::end($name);
     return $l;
 }
 
-sub exception {
-    my $self = shift;
+sub exception($) {
+    my($self) = shift;
     return $self->{"exception"};
 }
 
-sub result {
-    my $self = shift;
+sub result($) {
+    my($self) = shift;
     return $self->{"result"};
 }
 
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-BZ::Client::XMLRPC::Response
-
-=head1 VERSION
-
-version 1.062_2
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Dean Hamstead <dean@bytefoundry.com.au>
-
-=item *
-
-Jochen Wiedmann <jochen.wiedmann@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Dean Hamstad.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
